;**********************************************************************
;   This file is a basic code template for assembly code generation   *
;   on the PIC16F690. This file contains the basic code               *
;   building blocks to build upon.                                    *  
;                                                                     *
;   Refer to the MPASM User's Guide for additional information on     *
;   features of the assembler (Document DS33014).                     *
;                                                                     *
;   Refer to the respective PIC data sheet for additional             *
;   information on the instruction set.                               *
;                                                                     *
;**********************************************************************
;**********************************************************************
;				YOU HAVE MAIL TRANS.ASM   
;**********************************************************************

;DATE: May 17, 2013
; 5/50/2013  N&V
;VERSION: 1
;XTAL TYPE:  INTERNAL 4 MHZ
;WRITTEN BY: RON NEWTON
;GENERAL REGISTER STARTS @ 20h
;INTERRSUPT VECTOR = 04h
;END OF PROGRAM MEMORY = 1FFH
;COMMENTS:  
;RECEIVE KEY MUST BE THE SAME AS TRANSMIT KEY
;                                                             *
;**********************************************************************
;                                                                     *
;    Files Required: P16F690.INC                                      *
;                                                                     *
;**********************************************************************
; PORT DESCRIPTIONS
;1 VCC
;2 PHOTO, IR, MOTION		RA5
;3 TILT	/ SWITCH			RA4
;4 NC						RA3
;5 NC						RC5
;6 NC						RC4
;7 AMPLIFIER INPUT			RC3
;8 NC						RC6
;9 NC						RC7
;10 BCD						RB7
;11 BCD						RB6
;12 BCD						RB5
;13 BCD						RB4  
;14 WATER SENSOR			RC2
;15 NC			  			RC1
;16 DATA OUT				RC0		
;17 PDN						RA2
;18 TEMPERATURE COMPARATOR	RA0	
;19 COMPARATOR REF			RA1	VARIBLE VOTAGE REFERENCE
;20 						GROUND

;                                         *
;**********************************************************************


	list		p=16f690		; list directive to define processor
	#include	<P16F690.inc>		; processor specific variable definitions
	
	__CONFIG    _CP_OFF & _CPD_OFF & _BOR_OFF & _PWRTE_ON & _WDT_OFF & _INTRC_OSC_NOCLKOUT & _MCLRE_OFF & _FCMEN_OFF & _IESO_OFF


; '__CONFIG' directive is used to embed configuration data within .asm file.
; The labels following the directive are located in the respective .inc file.
; See respective data sheet for additional information on configuration word.


#DEFINE 	PHOTO			PORTA,5		
#DEFINE		TILT			PORTA,4
#DEFINE		DATA_OUT		PORTC,0
#DEFINE		PDN				PORTA,2





;***** VARIABLE DEFINITIONS

;NEW REGISTERS
W_TEMP			EQU		20H						;RIGHT HAND DIGIT
PCLATH_TEMP		EQU		21H
STATUS_TEMP		EQU		22H
COUNTER			EQU		23H
COUNTER1		EQU		24H	
COUNTER2		EQU		25H
FLAG			EQU		26H	
COUNTER3		EQU		27H
HUMIDITY		EQU		28H
HUMIDITY_RESULT	EQU		29H
TIMER1			EQU		2AH
XMT_BYTE		EQU		2BH
LOOP1			EQU		2EH
LOOP2			EQU		2FH
TRANSPOND		EQU		30H
BIT_CNTR		EQU		31H
BIT_CNTR1		EQU		32H
RCV_BYTE		EQU		33H
KEY1TRANS		EQU		34H
RCV_BYTE1		EQU		35H
KEY2TRANS		EQU		36H
KEY1			EQU		37H
TEMP			EQU		38H
KEY2			EQU		39H
DELAY_CNTR		EQU		3AH
RESULTS			EQU		3BH
XMT_BYTE1		EQU		3CH
VALVE#			EQU		3DH
DELAY_CNTR1		EQU		3EH
XMT_BYTE2		EQU		3FH
BIT_CNTR2		EQU		40H
WAIT			EQU		41H
DELAY0			EQU		42H
DELAY1			EQU		43H
DELAY2			EQU		44H
TRANS1			EQU		45H
READING			EQU		46H
READING1		EQU		47H
w_temp			EQU		48H			; variable used for context saving
status_temp		EQU		49H			; variable used for context saving
pclath_temp		EQU		4AH			; variable used for context saving
AGAIN			EQU		4BH	
COUNTER4		EQU		4CH
COUNTER5		EQU		4DH
COUNTER6		EQU		4EH
;**********************************************************************
	ORG		0x000				; processor reset vector
  	goto		main			; go to beginning of program


	ORG		0x004				; interrupt vector location
	movwf		w_temp			; save off current W register contents
	movf		STATUS,w		; move status register into W register
	movwf		status_temp		; save off contents of STATUS register
	movf		PCLATH,w		; move pclath register into W register
	movwf		pclath_temp		; save off contents of PCLATH register
	BANKSEL		PORTA			; MAKE SURE IN RIGHT BANK
	MOVF		PORTA,1			; READ PORT A TO PREVENT INTERRUPT
	BCF			INTCON,RABIF	; clear interrupt
	BANKSEL		CM1CON0			; CHANGE BANK
	MOVF		CM1CON0,1		; READ CM2CON0 TO PREVENT INTERRUPT
	BANKSEL		PORTA			; CHANGE BANK
	CLRF		PIR2			;clear interrupt	
	movf		pclath_temp,w	; retrieve copy of PCLATH register
	movwf		PCLATH			; restore pre-isr PCLATH register contents	
	movf		status_temp,w	; retrieve copy of STATUS register
	movwf		STATUS			; restore pre-isr STATUS register contents
	swapf		w_temp,f
	swapf		w_temp,w		; restore pre-isr W register contents
	retfie						; return from interrupt


main
		MOVLW		0AAH		;LOADING KEY
		MOVWF		KEY1		;LOAD

INITIALIZING								;LABEL FOR INTIALIZING MICRO

		BANKSEL		PORTA					;MAKE SURE IN RIGHT BANK
		CLRF		PORTA					;CLEAR PORT A
;		BANKSEL		TRISA					;MAKE SURE IN RIGHT BANK
;		MOVLW		B'00110011				;LOAD
;		MOVWF		TRISA 					;LOADING TRISA		B'00110011'
		BANKSEL		PORTB					;MAKE SURE IN RIGHT BANK
		CLRF		PORTB					;CLEAR PORT B
		BANKSEL		TRISB					;MAKE SURE IN RIGHT BANK
		MOVLW		B'11110000'				;PORT B SWITCHES
		MOVWF		TRISB					;LOADING TRISB
		BANKSEL		PORTC					;MAKE SURE IN RIGHT BANK
		CLRF		PORTC					;CLEAR PORT C
		BANKSEL		TRISC					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00001100'				;LOAD
		MOVWF		TRISC					;MAKE TRISC 	
		BANKSEL		WPUA					;MAKE SURE IN RIGHT BANK
		CLRF		WPUA					;LOAD
		BANKSEL		WPUB					;MAKE SURE IN RIGHT BANK
		MOVLW		B'11110000'				;SET PULL UPS FOR SWITCH
		MOVWF		WPUB					;LOAD
		BANKSEL		OPTION_REG				;CHANGE BANK
		CLRF		OPTION_REG				;LOAD
		BANKSEL		ANSEL					;MAKE SURE IN RIGHT BANK
		MOVLW		B'10000011'				;MAKE RA0, RA1 ANALOG
		MOVWF		ANSEL					;SET ANALOG AND DIGITAL INPUTS		
		CLRF		ANSELH					;SET ANALOG AND DIGITAL INPUTS
		BANKSEL		SRCON					;CHANGE BANK
		CLRF		SRCON					;SRCON NOT NEEDED
		BANKSEL		CM2CON0					;CHANGE BANK
		CLRF		CM2CON0					;CLEAR CM2CON0
		BANKSEL		PORTA					;MAKE SURE IN RIGHT BANK		
		BCF			PDN						;TURN OFF TRANSMITTER POWER

;*******************************STARTING UP ************************

TESTING								;LABEL TESTING AREA


	GOTO	START


	CALL	SENDING
		MOVLW	.3
		MOVWF	XMT_BYTE1
		MOVLW	.10
		MOVWF	COUNTER2
T1		DECFSZ	COUNTER,1
		GOTO	T1
		DECFSZ	COUNTER1,1
		GOTO	T1
		DECFSZ	COUNTER2,1
		GOTO	T1

		
		GOTO	TESTING
		
;*****************STARTING OF PROGRAM ********************
START 
;***************PHOTO CHANGE DETECTS LIGHT *************
		MOVLW		0F0H					;PUT IN ROTARY SWITCH 0
		SUBWF		PORTB,0					;CHECK PORTC
		BTFSS		3,2						;CHECK FOR MATCH
		GOTO		S1						;NOT THE SAME JUMP
		NOP
		BANKSEL		TRISA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00100000'				;LOAD
		MOVWF		TRISA 					;LOADING TRISA	

		BANKSEL		WPUA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00100000'				;SET PULL UPS PIN 2 RA5
		MOVWF		WPUA					;LOAD
		BANKSEL		PIE1					;CHANGE BANK
		CLRF		PIE1					;LOAD
		CLRF		PIE2					;LOAD
		BANKSEL		IOCA					;CHANGE BANK
		MOVLW		B'00100000'				;MAKE RA5 INTERRUPT
		MOVWF		IOCA					;LOAD
		BANKSEL		PORTA					;CHANGE BANK
		BTFSC		PHOTO					;MAKE SURE PHOTO IS HIGH  (NO LIGHT)
		DECFSZ		COUNTER,1				;DELAY
		GOTO		$-2		
		MOVF		PORTA,1					;READ PORTA FOR CHANGE
		MOVLW		B'11001000'				;ALLOW INTERRUPTS
		MOVWF		INTCON					;LOAD
		SLEEP								;PUT TO SLEEP

		BCF			INTCON,GIE				;TURN OFF INTERRUPT
		CALL		SEND					;SEND DATA
		GOTO		START					;RETURN TO START

;***************PHOTO CHANGE DETECTS NO LIGHT*************
S1		MOVLW		0E0H					;PUT IN ROTARY SWITCH 1
		SUBWF		PORTB,0					;CHECK PORTC
		BTFSS		3,2						;CHECK FOR MATCH
		GOTO		S2						;NOT THE SAME JUMP
		NOP
		BANKSEL		TRISA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00100000'				;LOAD
		MOVWF		TRISA 	
		BANKSEL		WPUA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00100000'				;SET PULL UPS PIN 2 RA5
		MOVWF		WPUA					;LOAD
		BANKSEL		PIE1					;CHANGE BANK
		CLRF		PIE1					;LOAD
		CLRF		PIE2					;LOAD
		BANKSEL		IOCA					;CHANGE BANK
		MOVLW		B'00100000'				;MAKE RA5 INTERRUPT
		MOVWF		IOCA					;LOAD
		BANKSEL		PORTA
		BTFSS		PHOTO					;MAKE SURE PHOTO IS LOW (LIGHT ON)
		DECFSZ		COUNTER,1				;DELAY
		GOTO		$-2
		MOVF		PORTA,1					;READ PORTA FOR CHANGE		
		MOVLW		B'11001000'				;ALLOW INTERRUPTS
		MOVWF		INTCON					;LOAD			
		SLEEP								;PUT TO SLEEP

		BCF			INTCON,GIE				;TURN OFF INTERRUPT
		CALL		SEND					;SEND DATA
P1		GOTO		S1						;RETURN TO START

;***************PROXIMITY DETECTOR DETECTS MOVEMENT ***************
S2		MOVLW		0D0H					;PUT IN ROTARY SWITCH 2
		SUBWF		PORTB,0					;CHECK WITH PORTC
		BTFSS		3,2						;CHECK FOR MATCH
		GOTO		S3						;NOT THE SAME JUMP
		NOP
		BANKSEL		TRISA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00100000'				;LOAD
		MOVWF		TRISA 	
		BANKSEL		WPUA					;MAKE SURE IN RIGHT BANK
		CLRF		WPUA					;NO PULL UP
		BANKSEL		PIE1					;CHANGE BANK
		CLRF		PIE1					;LOAD
		CLRF		PIE2					;LOAD
		BANKSEL		IOCA					;CHANGE BANK
		MOVLW		B'00100000'				;MAKE RA5 INTERRUPT
		MOVWF		IOCA					;LOAD
		BANKSEL		PORTA
		BTFSC		PHOTO					;MAKE SURE PHOTO GOES LOW
		GOTO		$-1
		MOVF		PORTA,1					;READ PORTA FOR CHANGE
		MOVLW		B'11001000'				;ALLOW INTERRUPTS
		MOVWF		INTCON					;LOAD					
		SLEEP								;PUT TO SLEEP
		BCF			INTCON,GIE				;TURN OFF INTERRUPT
		CALL		SEND					;SEND DATA
		GOTO		S2						;RETURN TO START

;***************PROXIMITY DETECTOR DETECTS NO MOVEMENT ***************
S3		MOVLW		0C0H					;PUT IN ROTARY SWITCH 3
		SUBWF		PORTB,0					;CHECK WITH PORTC
		BTFSS		3,2						;CHECK FOR MATCH
		GOTO		S4						;NOT THE SAME JUMP
		NOP
		BANKSEL		TRISA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00100000'				;LOAD
		MOVWF		TRISA 	
		BANKSEL		WPUA					;MAKE SURE IN RIGHT BANK
		CLRF		WPUA					;NO PULL UP
		BANKSEL		PIE1					;CHANGE BANK
		CLRF		PIE1					;LOAD
		CLRF		PIE2					;LOAD
		BANKSEL		IOCA					;CHANGE BANK
		MOVLW		B'00100000'				;MAKE RA5 INTERRUPT
		MOVWF		IOCA					;LOAD
		BANKSEL		PORTA
		BTFSS		PHOTO					;MAKE SURE PHOTO IS HIGH
		GOTO		$-1
		MOVF		PORTA,1					;READ PORTA FOR CHANGE	
		MOVLW		B'11001000'				;ALLOW INTERRUPTS
		MOVWF		INTCON					;LOAD				
		SLEEP								;PUT TO SLEEP

		BCF			INTCON,GIE				;TURN OFF INTERRUPT
		CALL		SEND					;SEND DATA
		GOTO		S3						;RETURN TO START

;***************TILT CHANGE NORMALY CLOSED WITH DELAY*************
S4		MOVLW		0B0H					;PUT IN ROTARY SWITCH 4
		SUBWF		PORTB,0					;CHECK WITH PORTC
		BTFSS		3,2						;CHECK FOR MATCH
		GOTO		S5						;NOT THE SAME JUMP
		NOP
		BANKSEL		TRISA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00010000'				;LOAD
		MOVWF		TRISA 	
		BANKSEL		WPUA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00010000'				;SET PULL UPS RA4
		MOVWF		WPUA					;LOAD
		BANKSEL		PIE1					;CHANGE BANK
		CLRF		PIE1					;LOAD
		CLRF		PIE2					;LOAD
		BANKSEL		IOCA					;CHANGE BANK
		MOVLW		B'00010000'				;MAKE RA4 INTERRUPT
		MOVWF		IOCA					;LOAD
		BANKSEL		PORTA					;CHANGE BANK
		BTFSC		TILT					;CHECK TILT SWITCH
		GOTO		$-1						;TILT LOW JUMP		
		MOVF		PORTA,1					;READ PORTA FOR CHANGE
		MOVLW		B'11001000'				;ALLOW INTERRUPTS
		MOVWF		INTCON					;LOAD		
		SLEEP								;PUT TO SLEEP

		BSF			INTCON,GIE				;TURN OFF INETERRUPT
		MOVLW		.3
		MOVWF		COUNTER2
S4A		BTFSS		TILT					;THIS CAUSES 1 SECOND DELAY
		GOTO		S4
		DECFSZ		COUNTER,1
		GOTO		S4A
		DECFSZ		COUNTER1,1
		GOTO		S4A
		DECFSZ		COUNTER2,1
		GOTO		S4A
		CALL		SEND					;TILT HIGH ALARM
		GOTO		S4						;RETURN TO START

;***************TILT CHANGE NORMALLY OPEN WITH DELAY*************
S5		MOVLW		0A0H					;PUT IN ROTARY SWITCH 5
		SUBWF		PORTB,0					;CHECK WITH PORTC
		BTFSS		3,2						;CHECK FOR MATCH
		GOTO		S6						;NOT THE SAME JUMP
		NOP
		BANKSEL		TRISA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00010000'				;LOAD
		MOVWF		TRISA 	
		BANKSEL		WPUA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00010000'				;SET PULL UPS RA4
		MOVWF		WPUA					;LOAD
		BANKSEL		PIE1					;CHANGE BANK
		CLRF		PIE1					;LOAD
		CLRF		PIE2					;LOAD
		BANKSEL		IOCA					;CHANGE BANK
		MOVLW		B'00010000'				;MAKE RA4 INTERRUPT
		MOVWF		IOCA					;LOAD
		BANKSEL		PORTA
		BTFSS		TILT
		GOTO		$-1
		MOVF		PORTA,1					;READ PORTA FOR CHANGE
		MOVLW		B'11001000'				;ALLOW INTERRUPTS
		MOVWF		INTCON					;LOAD		
		SLEEP								;PUT TO SLEEP

		BCF			INTCON,GIE				;TURN OFF INTERRUPT
		MOVLW		.3
		MOVWF		COUNTER2
S5A		BTFSC		TILT					;THIS CAUSES 1 SECOND DELAY
		GOTO		S5
		DECFSZ		COUNTER,1
		GOTO		S5A
		DECFSZ		COUNTER1,1
		GOTO		S5A
		DECFSZ		COUNTER2,1
		GOTO		S5A
		CALL		SEND					;TILT HIGH ALARM
		GOTO		S5						;RETURN TO S5

;*******************SWITCH CHANGE CHANGE  ****************

S6		MOVLW		090H					;PUT IN ROTARY SWITCH 6
		SUBWF		PORTB,0					;CHECK WITH PORTC
		BTFSS		3,2						;CHECK FOR MATCH
		GOTO		S7						;NOT THE SAME JUMP
		NOP
		BANKSEL		TRISA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00010000'				;LOAD
		MOVWF		TRISA 	
		BANKSEL		WPUA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00010000'				;SET PULL UPS RA4
		MOVWF		WPUA					;LOAD
		CLRF		PIE1					;LOAD
		CLRF		PIE2					;LOAD
		BANKSEL		IOCA					;CHANGE BANK
		MOVLW		B'00010000'				;MAKE RA4 INTERRUPT
		MOVWF		IOCA					;LOAD
		BANKSEL		PORTA					;MAKE SURE IN RIGHT BANK
		MOVF		PORTA,1					;READ PORTA FOR CHANGE
		MOVLW		B'11001000'				;ALLOW INTERRUPTS
		MOVWF		INTCON					;LOAD
		SLEEP								;PUT TO SLEEP
		
		BCF			INTCON,GIE				;TURN OFF INTERRUPTS
		CALL		SEND					;NO HIGH ALARM
		GOTO		S6						;RETURN TO S6



;***************NO WATER PRESENT  ALSO USED BY VIBATION AND SOUND*************
S7		MOVLW		080H					;PUT IN ROTARY SWITCH 7
		SUBWF		PORTB,0					;CHECK WITH PORTC
		BTFSS		3,2						;CHECK FOR MATCH
		GOTO		S8						;NOT THE SAME JUMP
		NOP
		BANKSEL		TRISA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00000000'				;LOAD
		MOVWF		TRISA 	
		BANKSEL		INTCON					;MAKE SURE IN RIGHT BANK
		MOVLW		B'11000000'				;ALLOW INTERRUPTS
		MOVWF		INTCON					;LOAD
		BANKSEL		PIE1					;CHANGE BANK
		MOVLW		B'00000100'				;LOAD PIE1 FOR INTERRUPT ON COMPARATOR
		MOVWF		PIE1					;LOAD
		MOVLW		B'00100000'				;COMPARATOR INTERRUPT
		MOVWF		PIE2					;LOAD
		BANKSEL		CM1CON0					;CHANGE BANK
		MOVLW		B'10000110'				;INTERNAL REF PIN 14
		MOVWF		CM1CON0					;LOAD
		BANKSEL		VRCON					;CHANGE BANK
		MOVLW		B'10101100'				;REFERENCE ON .625 VOLTS TO C1+
		MOVWF		VRCON					;LOAD
		BANKSEL		PORTA					;CHANGE BANK
		MOVF		PORTA,1					;READ PORTA FOR CHANGE
		SLEEP								;PUT TO SLEEP
		DECFSZ		COUNTER1,1				;DELAY
		GOTO		$-1
		BANKSEL		CM1CON0					;CHANGE BANK
		BTFSC		CM1CON0,C1OUT			;CHECK FOR WATER LEVEL
		GOTO		S7A						;CHANGE JUMP
		BANKSEL		PORTA					;CHANGE BANK
		GOTO		S7						;NO WATER JUMP
S7A		NOP	
		BANKSEL		PORTA					;CHANGE BANK
		CALL		SEND					;WATER PRESENT ALARM
		GOTO		S7						;RETURN TO START

;***************WATER PRESENT*************
S8		MOVLW		070H					;PUT IN ROTARY SWITCH 8
		SUBWF		PORTB,0					;CHECK WITH PORTC
		BTFSS		3,2						;CHECK FOR MATCH
		GOTO		S9						;JUMP
		NOP
		BANKSEL		TRISA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00000000'				;LOAD
		MOVWF		TRISA 
		BANKSEL		INTCON					;MAKE SURE IN RIGHT BANK
		MOVLW		B'11000000'				;ALLOW INTERRUPTS
		MOVWF		INTCON					;LOAD
		BANKSEL		PIE1					;CHANGE BANK
		MOVLW		B'00000100'				;LOAD PIE1 FOR INTERRUPT ON COMPARATOR
		MOVWF		PIE1					;LOAD
		MOVLW		B'00100000'				;COMPARATOR INTERRUPT
		MOVWF		PIE2					;LOAD
		BANKSEL		CM1CON0					;CHANGE BANK
		MOVLW		B'10000110'				;INTERNAL REF PIN 14
		MOVWF		CM1CON0					;LOAD
		BANKSEL		VRCON					;CHANGE BANK
		MOVLW		B'10101100'				;REFERENCE ON .625 VOLTS TO C1+
		MOVWF		VRCON					;LOAD
		BANKSEL		PORTA					;CHANGE BANK
		MOVF		PORTA,1					;READ PORTA FOR CHANGE
		SLEEP								;PUT TO SLEEP

		DECFSZ		COUNTER1,1				;DELAY
		GOTO		$-1
		BANKSEL		CM1CON0					;CHANGE BANK
		BTFSS		CM1CON0,C1OUT			;CHECK C1OUT
		GOTO		S8A						;JUMP
		BANKSEL		PORTA					;CHANGE BANK
		GOTO		S8						;WATER PRESENT JUMP
S8A		NOP
		BANKSEL		PORTA
		CALL		SEND					;NO WATER PRESENT ALARM
		GOTO	S8							;RETURN TO START

;*************AMP ABOVE REFERENCE***********
S9		MOVLW		060H					;PUT IN ROTARY SWITCH 9
		SUBWF		PORTB,0					;CHECK WITH PORTC
		BTFSS		3,2						;CHECK FOR MATCH
		GOTO		S10						;NOT THE SAME JUMP
		NOP
		BANKSEL		TRISA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00000010'				;LOAD
		MOVWF		TRISA 

		BANKSEL		PIE1					;CHANGE BANK
		MOVLW		B'00000100'				;LOAD PIE1 FOR INTERRUPT ON COMPARATOR
		MOVWF		PIE1					;LOAD
		MOVLW		B'00100000'				;COMPARATOR INTERRUPT
		MOVWF		PIE2					;LOAD

		BANKSEL		CM1CON0					;CHANGE BANK
		MOVLW		B'10000011'				;MAKE ACTIVE PIN 7
		MOVWF		CM1CON0					;MOVE
		NOP									;SETTLING DELAY
		NOP
		NOP
		MOVF		CM1CON0,1
		BANKSEL		PORTA					;CHANGE BANK
		CLRF		PIR1					;CLEAR INTERRUPT
		MOVLW		B'11000000'				;ALLOW INTERRUPTS
		MOVWF		INTCON					;LOAD
		SLEEP								;PUT TO SLEEP
		NOP

		BCF			INTCON,GIE				;TURN OFF INTERRUPT
S9A		NOP									;ANTICHATTER DELAY
		BANKSEL		CM1CON0					;CHANGE BANK
		MOVF		CM1CON0,1				;READ CM1CON0
		BTFSC		CM1CON0,6				;CHECK STATUS
		GOTO		S9						;CHATTER JUMP
		NOP
		BANKSEL		PORTA					;CHANGE BANKS
		DECFSZ		COUNTER1,1				;DELAY COUNTER
		GOTO		S9A						;JUMP
		DECFSZ		COUNTER2,1				;DELAY
		GOTO		S9A
		NOP
		BANKSEL		PORTA					;CHANGE BANKS
		CALL		SEND					;AMP ABOVE REFERENCE JUMP
		GOTO		S9						;RETURN TO S9

;*************AMP BELOW REFERENCE***********
S10		MOVLW		050H					;PUT IN ROTARY SWITCH A
		SUBWF		PORTB,0					;CHECK WITH PORTC
		BTFSS		3,2						;CHECK FOR MATCH
		GOTO		S11						;NOT THE SAME JUMP
		NOP
		BANKSEL		TRISA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00000010'				;LOAD
		MOVWF		TRISA 
		BANKSEL		PIE1					;CHANGE BANK
		MOVLW		B'00000100'				;LOAD PIE1 FOR INTERRUPT ON COMPARATOR
		MOVWF		PIE1					;LOAD
		MOVLW		B'00100000'				;COMPARATOR INTERRUPT
		MOVWF		PIE2					;LOAD

		BANKSEL		CM1CON0					;CHANGE BANK
		MOVLW		B'10000011'				;MAKE ACTIVE PIN 7
		MOVWF		CM1CON0					;MOVE
		NOP									;SETTLING DELAY
		NOP
		NOP
		MOVF		CM1CON0,1
		BANKSEL		PORTA					;CHANGE BANK
		CLRF		PIR1					;CLEAR INTERRUPT
		MOVLW		B'11000000'				;ALLOW INTERRUPTS
		MOVWF		INTCON					;LOAD

		SLEEP								;PUT TO SLEEP
		NOP
		BCF			INTCON,GIE				;TURN OFF INTERRUPT
S10A	NOP									;ANTICHATTER DELAY
		BANKSEL		CM1CON0					;CHANGE BANK
		MOVF		CM1CON0,1				;READ CM1CON0
		BTFSS		CM1CON0,6				;CHECK STATUS
		GOTO		S10						;CHATTER JUMP
		NOP
		BANKSEL		PORTA					;CHANGE BANK
		DECFSZ		COUNTER1,1				;DELAY FOR ANTI CHATTER
		GOTO		S10A					;JUMP
		DECFSZ		COUNTER2,1
		GOTO		S10A
		NOP
		BANKSEL		PORTA
		CALL		SEND					;AMP ABOVE REFERENCE JUMP
		GOTO		S10						;RETURN TO START

;***************TEMPERATURE ABOVE  *************
S11		MOVLW		040H					;PUT IN ROTARY SWITCH B
		SUBWF		PORTB,0					;CHECK WITH PORTC
		BTFSS		3,2						;CHECK FOR MATCH
		GOTO		S12						;NOT THE SAME JUMP
		NOP
		BANKSEL		TRISA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00000011'				;LOAD
		MOVWF		TRISA 
		BANKSEL		PIE1					;CHANGE BANK
		MOVLW		B'00000100'				;LOAD PIE1 FOR INTERRUPT ON COMPARATOR
		MOVWF		PIE1					;LOAD
		MOVLW		B'00100000'				;COMPARATOR INTERRUPT
		MOVWF		PIE2					;LOAD

		BANKSEL		CM1CON0					;CHANGE BANK
		MOVLW		B'10000000'				;MAKE ACTIVE PIN 18
		MOVWF		CM1CON0					;MOVE
		NOP									;SETTLING DELAY
		NOP
		NOP
		MOVF		CM1CON0,1				;READ FOR MISMATCH
		BANKSEL		PORTA					;CHANGE BANK
		CLRF		PIR1					;CLEAR INTERRUPT FLAG
		MOVLW		B'11000000'				;ALLOW INTERRUPTS
		MOVWF		INTCON					;LOAD

		SLEEP								;PUT TO SLEEP
		NOP
		BCF			INTCON,GIE				;TURN OFF INTERRUPT
		MOVLW		.5
		MOVWF		COUNTER3
S11A	NOP									;ANTICHATTER DELAY
		BANKSEL		CM1CON0					;CHANGE BANK
		MOVF		CM1CON0,1				;READ CM1CON0
		BTFSS		CM1CON0,6				;CHECK STATUS
		GOTO		S11						;JUMP
		NOP
		BANKSEL		PORTA					;CHANGE BANK
		DECFSZ		COUNTER1,1				;DELAY FOR CHATTER
		GOTO		S11A					;JUMP
		DECFSZ		COUNTER2,1
		GOTO		S11A
		DECFSZ		COUNTER3,1
		GOTO		S11A
		CALL		SEND		
		GOTO		S11

;***************TEMPERATURE BELOW*************
S12		MOVLW		030H					;PUT IN ROTARY SWITCH C
		SUBWF		PORTB,0					;CHECK WITH PORTC
		BTFSS		3,2						;CHECK FOR MATCH
		GOTO		S13
		NOP
		BANKSEL		TRISA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00000011'				;LOAD
		MOVWF		TRISA 
		BANKSEL		PIE1					;CHANGE BANK
		MOVLW		B'00000100'				;LOAD PIE1 FOR INTERRUPT ON COMPARATOR
		MOVWF		PIE1					;LOAD
		MOVLW		B'00100000'				;COMPARATOR INTERRUPT
		MOVWF		PIE2					;LOAD

		BANKSEL		CM1CON0					;CHANGE BANK
		MOVLW		B'10000000'				;MAKE ACTIVE PIN 18
		MOVWF		CM1CON0					;MOVE
		NOP									;SETTLING DELAY
		NOP
		NOP
		MOVF		CM1CON0,1				;READ FOR MISMATCH
		BANKSEL		PORTA					;CHANGE BANK
		CLRF		PIR1					;CLEAR INTERRUPT FLAG
		MOVLW		B'11000000'				;ALLOW INTERRUPTS
		MOVWF		INTCON					;LOAD

		SLEEP								;PUT TO SLEEP
		NOP
		BCF			INTCON,GIE				;TURN OFF INTERRUPT
		MOVLW		.5						;LOAD DELAY
		MOVWF		COUNTER3				;LOAD
S12A	NOP									;ANTICHATTER DELAY
		BANKSEL		CM1CON0					;CHANGE BANK
		MOVF		CM1CON0,1				;READ CM1CON0
		BTFSC		CM1CON0,6				;CHECK STATUS
		GOTO		S12	
		NOP
		BANKSEL		PORTA
		DECFSZ		COUNTER1,1
		GOTO		S12A
		DECFSZ		COUNTER2,1
		GOTO		S12A
		DECFSZ		COUNTER3,1
		GOTO		S12A
		CALL		SEND		
		GOTO		S12

;***************INTRUSION DETECTING IR*************
S13		MOVLW		020H					;PUT IN ROTARY SWITCH D
		SUBWF		PORTB,0					;CHECK WITH PORTC
		BTFSS		3,2						;CHECK FOR MATCH
		GOTO		S14  
		NOP
		BANKSEL		TRISA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00100000'				;LOAD
		MOVWF		TRISA 
		BANKSEL		PORTA
		CLRF		INTCON
		GOTO		S13A
S13AA	BCF			FLAG,1
		MOVLW		.12						;SETS DELAY FOR SENSITIVITY
		MOVWF		COUNTER1
S13A	BTFSS		PORTA,5					
		GOTO		S13AA
		DECFSZ		COUNTER,1
		GOTO		S13A
		DECFSZ		COUNTER1,1
		GOTO		S13A

S13B	BTFSC		FLAG,1
		GOTO		S13
		CALL		SEND
		BSF			FLAG,1
 		GOTO		S13
;***************INTRUSION DETECTING NO IR*************
S14		MOVLW		010H					;PUT IN ROTARY SWITCH E
		SUBWF		PORTB,0					;CHECK WITH PORTC
		BTFSS		3,2						;CHECK FOR MATCH
		GOTO		S15     
		NOP 
		BANKSEL		TRISA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00100000'				;LOAD
		MOVWF		TRISA 
		BANKSEL		PORTA
		CLRF		INTCON
S14B	BTFSC		FLAG,1
		GOTO		S14E
		CALL		SEND
		BSF			FLAG,1
		
S14E	MOVLW		.12						;SETS DELAY FOR SENSITIVITY
		MOVWF		COUNTER1
S14A	BTFSS		PORTA,5				
		GOTO		S14
		DECFSZ		COUNTER,1
		GOTO		S14A
		DECFSZ		COUNTER1,1
		GOTO		S14A	
		BCF			FLAG,1
		GOTO		S14E


;******************SOUND***********************
S15		MOVLW		000H					;PUT IN ROTARY SWITCH F
		SUBWF		PORTB,0					;CHECK WITH PORTC
		BTFSS		3,2						;CHECK FOR MATCH
		GOTO		START   
		NOP
		BANKSEL		TRISA					;MAKE SURE IN RIGHT BANK
		MOVLW		B'00000010'				;LOAD
		MOVWF		TRISA 

		BANKSEL		PIE1					;CHANGE BANK
		MOVLW		B'00000100'				;LOAD PIE1 FOR INTERRUPT ON COMPARATOR
		MOVWF		PIE1					;LOAD
		MOVLW		B'00100000'				;COMPARATOR INTERRUPT
		MOVWF		PIE2					;LOAD
		BANKSEL		CM1CON0					;CHANGE BANK
		MOVLW		B'10000011'				;MAKE ACTIVE PIN 7
		MOVWF		CM1CON0					;MOVE
		NOP
		NOP
		NOP
		MOVF		CM1CON0,1				;READ CM1CON0
		BANKSEL		PORTA					;CHANGE BANK
		MOVF		PORTA,1					;READ PORTA FOR CHANGE
		CLRF		PIR1					;CLEAR INTERRUPT
		MOVLW		B'11000000'				;ALLOW INTERRUPTS
		MOVWF		INTCON					;LOAD
		SLEEP								;PUT TO SLEEP
  		BANKSEL		PORTA
		CALL		SEND					;AMP BELOW REFERENCE JUMP
		GOTO		S15						;RETURN TO START


;*****************************************************************
;************************END OF ROTARY SWITCH*******************

; THIS PROGRAM FOR TESTING
DISPLAY
		BSF		PDN
		MOVLW	.5
		MOVWF	COUNTER2
		DECFSZ	COUNTER,1
		GOTO	$-1
		DECFSZ	COUNTER1,1
		GOTO	$-3
		DECFSZ	COUNTER2,1
		GOTO	$-5
		BCF		PDN
		RETURN

;THIS PROGRAM SENDS 10 TIMES		
		
SENDING
		MOVLW	.10					;SET NUMBER OF TIMES TO SEND
		MOVWF	AGAIN
SA1		CALL	SEND				;CALL SEND
		DECFSZ	AGAIN,1				;DO AGAIN
		GOTO	SA1					;DELAY
		MOVLW	.80
		MOVWF	COUNTER4

		RETURN		
		
		
;********************RS232 INSTRUCTIONS***********
BIT_DELAY 
		MOVLW	D'200'			   	;GENERATING 1200 BAUD DELAY
		MOVWF	DELAY_CNTR         	;LOAD INTO COUNTER
LOOP_1	NOP
		DECFSZ	DELAY_CNTR,1
		GOTO	LOOP_1
        RETLW   0                   ;RETURN TO CALL 
START_DELAY							;LABEL
		MOVLW		D'100'		   	;SETUP FOR 1200 BAUD SETS FOR DETECTING MIDDLE OF BIT
		MOVWF		DELAY_CNTR	   	;DELAY LOOP
LOOP_2	NOP
		DECFSZ		DELAY_CNTR,1
		GOTO		LOOP_2	
	    RETLW 		0              	;RETURN TO CALL
 


	
;********************RS232 TRANSMITTER INSTRUCTIONS***********
SEND
		MOVF	KEY1,0				;PUTTING IN KEY CODE FOR TRANSMITTING
		MOVWF	XMT_BYTE
		BSF		PDN				   ;TURN ON TRANSMITTER POWER
		BSF		DATA_OUT		   ;KEEP DATA IN OUT HIGH
		MOVLW	.16				   ;PUT IN TRANSMIT DELAY
		MOVWF	WAIT
		CALL	BIT_DELAY		   ;KEEP HIGH FOR 20 BIT_DELAYS
		DECFSZ  WAIT,1
		GOTO	$-2
	  	MOVLW	D'8'			   ;LOAD 8 INTO W EIGHT BITS IN A BYTE
	    MOVWF	BIT_CNTR           ;LOAD
	    MOVWF	BIT_CNTR1
	    BCF	    DATA_OUT		   ;BRING DATA OUT LOW
        CALL    BIT_DELAY          ;START BIT SERIAL LOW FOR 1200 BAUD

XMIT    RRF     XMT_BYTE,1         ;ROTATE XMT BYTE FOR NEXT BIT
	    BTFSS	3,0				   ;CHECK TO SEE BIT SET
	    BCF		DATA_OUT	   	   ;NOT SET BRING SERIAL OUT LOW
	    BTFSC	3,0				   ;CHECK TO SEE IF SET	
	    BSF		DATA_OUT	   	   ;BIT SET MAKE SERIAL OUT HIGH
        CALL    BIT_DELAY          ;DATA BIT DELAY FOR 1200 BAUD
        DECFSZ 	BIT_CNTR,1		   ;CHECK TO SEE IT 8 BITS HAVE BEEN SENT
        GOTO	XMIT               ;DO UNITL EIGHT BITS ARE SENT
		BCF		DATA_OUT		   ;BRING DATA OUT LOW
		BCF		PDN				   ;TURN OFF POWER TO CHIP
        RETURN	                   ;RETURN 





	ORG	0x2100				; data EEPROM location
	DE	1,2,3,4				; define first four EEPROM locations as 1, 2, 3, and 4




	END                       ; directive 'end of program'

